
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef track_target_MSG_LIB_H
#define track_target_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "track_targetType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  TRACK_TARGET_MBOX_NAME                  genomInstanceName("track_target")

#define  TRACK_TARGET_MAX_RQST_SIZE              280

#define  TRACK_TARGET_MBOX_RQST_SIZE       \
 (BUF_SIZE(TRACK_TARGET_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  TRACK_TARGET_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  TRACK_TARGET_MAX_REPLY_SIZE             8

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  TRACK_TARGET_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(TRACK_TARGET_MAX_REPLY_SIZE) \
   + BUF_SIZE(TRACK_TARGET_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define TRACK_TARGET_INIT_RQST 0
#define TRACK_TARGET_ACTIVESEARCH_RQST 1
#define TRACK_TARGET_TRACK_RQST 2
#define TRACK_TARGET_TRACKSTOP_RQST 3
#define TRACK_TARGET_ABORT_RQST 4


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS track_targetClientInit (CLIENT_ID *pClientId);

STATUS track_targetClientEnd (CLIENT_ID clientId);

int track_targetAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int track_targetAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int track_targetAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS track_targetInitRqstSend (CLIENT_ID clientId, int *pRqstId,
					 TRACK_TARGET_INIT *(in_init_params),
					 int replyTimeOut);

extern int track_targetInitReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int track_targetInitRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					TRACK_TARGET_INIT *(in_init_params), 
					
					int *activity, int *bilan);

extern int track_targetInitRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					TRACK_TARGET_INIT *(in_init_params), 
					
					int *activity,
					int *bilan);




extern STATUS track_targetActiveSearchRqstSend (CLIENT_ID clientId, int *pRqstId,
					 TRACK_TARGET_SEARCH *(in_search_params),
					 int replyTimeOut);

extern int track_targetActiveSearchReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int track_targetActiveSearchRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					TRACK_TARGET_SEARCH *(in_search_params), 
					
					int *activity, int *bilan);

extern int track_targetActiveSearchRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					TRACK_TARGET_SEARCH *(in_search_params), 
					
					int *activity,
					int *bilan);




extern STATUS track_targetTrackRqstSend (CLIENT_ID clientId, int *pRqstId,
					 TRACK_TARGET_TRACK *(in_track_params),
					 int replyTimeOut);

extern int track_targetTrackReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int track_targetTrackRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					TRACK_TARGET_TRACK *(in_track_params), 
					
					int *activity, int *bilan);

extern int track_targetTrackRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					TRACK_TARGET_TRACK *(in_track_params), 
					
					int *activity,
					int *bilan);




extern STATUS track_targetTrackStopRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int track_targetTrackStopReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int track_targetTrackStopRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* track_target_MSG_LIB_H */

